model_urls = {
    "Bollig_2016": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/Bollig_2016.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/s11.2c_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/s11.2c_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/s11.2c_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/s27.0c_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/s27.0c_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Bollig_2016/s27.0c_LS220_nux",
    ],
    "Fornax_2019": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/Fornax_2019.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/grid.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_10M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_12M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_13M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_14M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_15M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_16M_r250.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_19M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_25M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_60M.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2019/lum_spec_9M.h5",
    ],
    "Fornax_2021": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/Fornax_2021.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_12M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_13M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_14M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_15M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_16M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_17M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_18M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_19M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_20M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_21M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_22M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_23M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_25M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_26.99M_r10000_dat.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Fornax_2021/lum_spec_26M_r10000_dat.h5",
    ],
    "Kuroda_2020": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Kuroda_2020/Kuroda_2020.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Kuroda_2020/LnuR00B00.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Kuroda_2020/LnuR10B12.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Kuroda_2020/LnuR10B13.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Kuroda_2020/README.md",
    ],
    "Nakazato_2013": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/Nakazato_2013.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-LS220-BH-z0.004-s30.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-BH-z0.004-s30.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev100ms-s13.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev100ms-s20.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev100ms-s50.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev200ms-s13.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev200ms-s20.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev200ms-s50.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev300ms-s13.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev300ms-s20.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.004-t_rev300ms-s50.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev100ms-s13.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev100ms-s20.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev100ms-s30.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev100ms-s50.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev200ms-s13.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev200ms-s20.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev200ms-s30.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev200ms-s50.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev300ms-s13.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev300ms-s20.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev300ms-s30.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-shen-z0.02-t_rev300ms-s50.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Nakazato_2013/nakazato-togashi-BH-z0.004-s30.0.fits",
    ],
    "OConnor_2013": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/HShen_datafiles.tar.gz",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/HShen_timeseries.tar.gz",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/HShen_timeseries_spectra.tar.gz",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/LS220_datafiles.tar.gz",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/LS220_timeseries.tar.gz",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/LS220_timeseries_spectra.tar.gz",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/OConnor_2013.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2013/read.py",
    ],
    "OConnor_2015": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2015/M1_neutrinos.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2015/OConnor_2015.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/OConnor_2015/README.md",
    ],
    "PISN": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/PISN/PISN_150Msun_EOS=Helm_NeutrinoFlux.tar.bz2",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/PISN/PISN_150Msun_EOS=SFHo_NeutrinoFlux.tar.bz2",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/PISN/PISN_250Msun_EOS=Helm_NeutrinoFlux.tar.bz2",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/PISN/PISN_250Msun_EOS=SFHo_NeutrinoFlux.tar.bz2",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/PISN/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/PISN/read.py",
    ],
    "Sukhbold_2015": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Sukhbold_2015/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Sukhbold_2015/Sukhbold_2015.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Sukhbold_2015/sukhbold-LS220-s27.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Sukhbold_2015/sukhbold-LS220-z9.6.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Sukhbold_2015/sukhbold-SFHo-s27.0.fits",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Sukhbold_2015/sukhbold-SFHo-z9.6.fits",
    ],
    "Tamborra_2014": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/Tamborra_2014.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s11.2c_3D_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s11.2c_3D_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s11.2c_3D_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s20.0c_3D_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s20.0c_3D_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s20.0c_3D_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir2_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir2_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir2_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir3_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir3_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Tamborra_2014/s27.0c_3D_dir3_LS220_nux",
    ],
    "Type_Ia": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Type_Ia/DDT_NeutrinoFlux.tar.bz2",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Type_Ia/GCD_NeutrinoFlux.tar.bz2",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Type_Ia/README.md",
    ],
    "Walk_2018": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/Walk_2018.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir2_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir2_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir2_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir3_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir3_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_fastrot_dir3_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir2_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir2_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir2_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir3_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir3_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_nonrot_dir3_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir2_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir2_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir2_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir3_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir3_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2018/s15.0c_3D_slowrot_dir3_LS220_nux",
    ],
    "Walk_2019": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/Walk_2019.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir2_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir2_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir2_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir3_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir3_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s40.0c_3DBH_dir3_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s75.0c_3DBH_dir1_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s75.0c_3DBH_dir1_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s75.0c_3DBH_dir1_LS220_nux",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s75.0c_3DBH_dir2_LS220_nue",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s75.0c_3DBH_dir2_LS220_nuebar",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Walk_2019/s75.0c_3DBH_dir2_LS220_nux",
    ],
    "Warren_2020": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/Warren_2020.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m10.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m10.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m10.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m10.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m100.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m11.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m11.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m11.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m11.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m12.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m12.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m12.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m12.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m120.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m13.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m14.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m15.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m16.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m17.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m18.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m19.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m20.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m21.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m22.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m23.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m24.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m25.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m26.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m27.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m28.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m29.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m30.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m31.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m32.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m33.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m35.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m40.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m45.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m50.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m55.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m60.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m70.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m80.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m9.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m9.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m9.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.23/stir_multimessenger_a1.23_m9.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m10.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m10.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m10.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m10.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m100.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m11.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m11.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m11.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m11.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m12.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m12.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m12.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m12.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m120.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m13.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m14.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m15.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m16.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m17.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m18.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m19.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m20.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m21.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m22.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m23.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m24.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m25.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m26.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m27.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m28.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m29.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m30.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m31.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m32.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m33.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m35.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m40.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m45.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m50.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m55.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m60.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m70.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m80.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m9.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m9.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m9.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.25/stir_multimessenger_a1.25_m9.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m10.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m10.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m10.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m10.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m100.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m11.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m11.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m11.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m11.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m12.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m12.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m12.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m12.75.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m120.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m13.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m14.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m15.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m16.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m17.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m18.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m19.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m20.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m21.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m22.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m23.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m24.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m25.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m26.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m27.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m28.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.1.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.2.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.3.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.4.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.6.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.7.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.8.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m29.9.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m30.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m31.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m32.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m33.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m35.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m40.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m45.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m50.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m55.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m60.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m70.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m80.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m9.0.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m9.25.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m9.5.h5",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Warren_2020/stir_a1.27/stir_multimessenger_a1.27_m9.75.h5",
    ],
    "Zha_2021": [
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/README.md",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/Zha_2021.ipynb",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s16.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s17.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s18.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s19.89.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s19.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s20.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s21.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s22.39.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s22.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s23.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s24.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s25.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s26.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s30.dat",
        "https://github.com/SNEWS2/snewpy/raw/v1.4b1/models/Zha_2021/s33.dat",
    ],
    "presn-models": [
    ],
}



# Licensed under a 3-clause BSD style license - see LICENSE.rst
# -*- coding: utf-8 -*-
"""
======
snewpy
======
Front-end for supernova models which provide neutrino luminosity and spectra.
"""

from ._version import __version__
from pathlib import Path
import os

try:
    from astropy.config.paths import get_cache_dir
except ModuleNotFoundError:
    # when imported by setup.py before dependencies are installed
    get_cache_dir = lambda: '.'

src_path = os.path.realpath(__path__[0])
base_path = os.sep.join(src_path.split(os.sep)[:-2])
model_path = os.path.join(get_cache_dir(), 'snewpy/models')

def get_models(models=None, download_dir='SNEWPY_models'):
    """Download model files from the snewpy repository.

    Parameters
    ----------
    models : list or str
        Models to download. Can be 'all', name of a single model or list of model names.
    download_dir : str
        Local directory to download model files to.
    """
    from concurrent.futures import ThreadPoolExecutor, as_completed
    from ._model_urls import model_urls
    from ._model_downloader import _download as download

    for model in list(model_urls):
        if model_urls[model] == []:
            del model_urls[model]
            continue

    if models == "all":
        models = model_urls.keys()
    elif isinstance(models, str):
        models = [models]
    elif models == None:
        # Select model(s) to download
        print(f"Available models in this version of SNEWPY: {list(model_urls.keys())}")
        if not model_urls:
            print("Error: `get_models()` only works after installing SNEWPY via `pip install snewpy`. "
                  "If you have cloned the git repo, model files are available in the `models/` folder.")
            return False

        selected = input("\nType a model name, 'all' to download all models or <Enter> to cancel: ").strip()
        if selected == "all":
            models = model_urls.keys()
        elif selected == "":
            exit()
        elif selected in model_urls.keys():
            models = [selected]
            while True:
                selected = input("\nType another model name or <Enter> if you have selected all models you want to download: ").strip()
                if selected in model_urls.keys():
                    models.append(selected)
                elif selected == "":
                    break
                else:
                    print(f"'{selected}' is not a valid model name. Please check for typos.")
        else:
            print(f"'{selected}' is not a valid model name. Please check for typos.")
            exit()

        print(f"\nYou have selected the models: {models}\n")

    # Download model files
    if not os.path.isdir(download_dir):
        print(f"Creating directory '{download_dir}' ...")
        os.makedirs(download_dir)

    pool = ThreadPoolExecutor(max_workers=8)
    results = []
    for model in models:
        model_dir = download_dir + '/' + model
        print(f"Downloading files for '{model}' into '{model_dir}' ...")

        for url in model_urls[model]:
            local_file = model_dir + url.split(model, maxsplit=1)[1]
            if os.path.exists(local_file) and local_file.find('README') == -1 and local_file.find('.ipynb') == -1:
                print(f"File '{local_file}' already exists. Skipping download.")
            else:
                if not os.path.isdir(os.path.dirname(local_file)):
                    os.makedirs(os.path.dirname(local_file))
                results.append(pool.submit(download, src=url, dest=Path(local_file)))

    exceptions = []
    for result in as_completed(results):
        if result.exception() is not None:
            exceptions.append(result.exception())
    if exceptions:
        print(f"ERROR: {len(exceptions)} exceptions occured. ({exceptions})")
        print("Please check your internet connection and try again later. If this persists, please report it at https://github.com/SNEWS2/snewpy/issues")
        exit(1)
    pool.shutdown(wait=False)


def _get_model_urls():
    """List URLs of model files for the current release.

    When building a snewpy release, generate a dictionary of available models
    and the URLs at which the respective files are located. Users can then use
    get_models() to interactively select which model(s) to download.
    """

    repo_dir = os.path.normpath(os.path.dirname(os.path.abspath(__file__)) + '/../../')
    url_base = 'https://github.com/SNEWS2/snewpy/raw/v' + __version__

    with open(os.path.dirname(os.path.abspath(__file__)) + '/_model_urls.py', 'w') as f:
        f.write('model_urls = {\n')
        for model in sorted(os.listdir(repo_dir + '/models')):
            urls = []
            for root, dirs, files in os.walk(repo_dir + '/models/' + model):
                for file in files:
                    urls.append(f'{url_base}{root[len(repo_dir):]}/{file}')

            f.write(f'    "{model}": [\n')
            for url in sorted(urls):
                f.write(f'        "{url}",\n')
            f.write('    ],\n')
        f.write('}\n')
